<?php
//
// +----------------------------------------------------------------------+
// | Search Engine Friendly URLs for zen-cart Open Source E-commerce      |
// +----------------------------------------------------------------------+
// | Copyright (c) 2005 Tim Kroeger                                       |
// | http://www.breakmyzencart.com                                        |
// |                                                                      |
// |                                                                      |
// |                                                                      |
// +----------------------------------------------------------------------+
// | This source file is subject to version 2.0 of the GPL license,       |
// | that is bundled with this package in the file LICENSE.txt, and is    |
// | available through the world-wide-web at the following url:           |
// | http://www.gnu.org/licenses/gpl.txt                                  |
// | If you did not receive a copy of the license and are unable          |
// | to obtain it through the world-wide-web, please send a note to       |
// | tim@breakmyzencart.com so I can mail you a copy immediately.         |
// +----------------------------------------------------------------------+
// $Id: functions_sefu.php,v 1.1.2.8 2005/05/21 19:51:00 tim Exp $

/**	
 * Helper functions for creation of Search Engine Friendly URLs
 * @author	Tim Kroeger <tim@breakmyzencart.com>
 * @version	0.3-beta1
 */

function sefu_clean_string($string){
	$string = strip_tags($string);
	// substitute some characters with a hyphen
	$string = ereg_replace('[ /_]', '-', $string);
	// substitute some characters with reasonable words
	$string = str_replace("&","-and-",$string);
	$string = str_replace("+","-plus-",$string);
	$string = str_replace("%","-percent",$string);
	$string = str_replace("@","-at-",$string);
	// convert string lowercase
	$string = strtolower($string);
	// substitute Umlauts and such
	$string = str_replace("","ae",$string);
	$string = str_replace("","oe",$string);
	$string = str_replace("","ue",$string);
	$string = str_replace("","ss",$string);
	// strip the rest of the unwanted characters
	$string = preg_replace('([^a-z0-9\-]*)', '', $string);
	// convert multiple hyphens to single hyphens
	while (strstr($string, '--')) $string = str_replace("--", "-", $string);
	return $string;
}

function sefu_parameters2path($parameters) {
	$path = str_replace('&amp;', '/', $parameters);
	$path = str_replace('?', '/', $path);
	$path = str_replace('&', '/', $path);
	$path = str_replace('=', '-', $path);

	$path = str_replace('main_page-', SEFU_PAGE_NAME . '-', $path);
	$path = str_replace('-' . FILENAME_DEFAULT, '-' . SEFU_MAIN_PAGE_NAME, $path);
	$path = str_replace('cPath-', SEFU_CATEGORY_NAME . '-', $path);
	$path = str_replace('products_id-', SEFU_PRODUCT_NAME . '-', $path);
	$path = str_replace('-' . FILENAME_PRODUCT_INFO, '-' . SEFU_PRODUCT_INFO_NAME, $path);

	return($path);
}

function sefu_path2parameters($path) {
	$parameters = str_replace(SEFU_PAGE_NAME . '-', 'main_page-', $path);
	$parameters = str_replace('-' . SEFU_MAIN_PAGE_NAME, '-' . FILENAME_DEFAULT, $parameters);
	$parameters = str_replace(SEFU_CATEGORY_NAME . '-', 'cPath-', $parameters);
	$parameters = str_replace(SEFU_PRODUCT_NAME . '-', 'products_id-', $parameters);
	$parameters = str_replace('-' . SEFU_PRODUCT_INFO_NAME, '-' . FILENAME_PRODUCT_INFO, $parameters);
	return rawurldecode($parameters);
}

function sefu_page_is_go($page) {
	$page_is_go = true;
	// these pages don't need to have Search-Engine Friendly URLs
	if (($page == FILENAME_ACCOUNT) or
			($page == FILENAME_ADVANCED_SEARCH) or
			($page == FILENAME_CHECKOUT_CONFIRMATION) or
			($page == FILENAME_CHECKOUT_PAYMENT) or
			($page == FILENAME_CHECKOUT_PAYMENT_ADDRESS) or
			($page == FILENAME_CHECKOUT_SHIPPING) or
			($page == FILENAME_CHECKOUT_SHIPPING_ADDRESS) or
			($page == FILENAME_CHECKOUT_SUCCESS) or
			($page == FILENAME_SHOPPING_CART) or
			// the next page breaks because of a parameter value that
			// might contain hyphens (used as parameter seperators :-( )
			
			//ok shouldn't break anymore but just to be sure...
			($page == FILENAME_POPUP_IMAGE_ADDITIONAL)) {
		$page_is_go = false;
	}
	return $page_is_go; 
}
?>